Summary: DHCPv6 - DHCP server and client for IPv6
Name:    dhcpv6
Version: 0.10
Release: 24_EL4
License: BSD
Group:   System Environment/Daemons
URL:     http://fedorahosted.org/dhcpv6/

Source0: http://dcantrel.fedorapeople.org/dhcpv6/dhcp-%{version}.tgz
Source1: rfc3315.txt
Source2: dhcp6s.sh
Source3: dhcp6r.sh

Patch0:  %{name}-0.10-initscripts.patch
Patch1:  %{name}-0.10-change_resolv_conf.patch
Patch2:  %{name}-0.10-bug_136146.patch
Patch3:  %{name}-0.10-yywrap.patch
Patch4:  %{name}-0.10-relay_agent.patch
Patch5:  %{name}-0.10-server_relay_support.patch
Patch6:  %{name}-0.10-install_relay_agent.patch
Patch7:  %{name}-0.10-bug_144585.patch
Patch8:  %{name}-0.10-prefix_delegation_interface.patch
Patch9:  %{name}-0.10-warnings.patch
Patch10: %{name}-0.10-use_glibc_ifaddrs.patch
Patch11: %{name}-0.10-165882.patch
Patch12: %{name}-0.10-bz217308.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: flex
BuildRequires: bison
BuildRequires: autoconf
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts

%description
Implements the Dynamic Host Configuration Protocol (DHCP) for Internet
Protocol version 6 (IPv6) networks in accordance with RFC 3315: Dynamic
Host Configuration Protocol for IPv6 (DHCPv6).  Consists of dhcp6s(8),
the server DHCP daemon, and dhcp6r(8), the DHCPv6 relay agent.  Install
this if you want to support dynamic configuration of IPv6 addresses and
parameters on your IPv6 network.  See man dhcp6s(8), dhcp6r(8),
dhcp6s.conf(5), and the documentation in /usr/share/doc/dhcpv6*.

%package -n dhcpv6_client
Summary:  DHCPv6 client
Requires: initscripts >= 7.73
Group:    System Environment/Base

%description -n dhcpv6_client
Provides the client for the DHCPv6 protocol (RFC 3315) to support dynamic
configuration of IPv6 addresses and parameters.  See man dhcp6c(8),
dhcp6c.conf(5), and the documentation in /usr/share/dhcpv6_client*.

%prep
%setup -q -n dhcp-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%{__rm} -f ifaddrs.h
%patch11 -p1
%patch12 -p1

%{__rm} -f dhcp6s.sh dhcp6r.sh dhcp6s.sysconfig dhcp6r.sysconfig

%{__cp} %{SOURCE2} .
%{__cp} %{SOURCE3} .

%{__cat} << EOF > dhcp6r.sysconfig
# Configuration for the DHCPv6 relay agent, dhcp6r
# Command line options here
DHCP6RARGS=
EOF

%{__cat} << EOF > dhcp6s.sysconfig
# specify the interface for dhcp6s
DHCP6SIF=
# Command line options here
DHCP6SARGS=
EOF

%build
export CFLAGS="%{optflags} -fPIE"
export LDFLAGS='-pie -Wl,-z,relro,-z,now,-z,nodlopen,-z,noexecstack'
autoconf
%configure

export CFLAGS="$CFLAGS -g -Wall"
%{__make}
%{__cp} -fp %{SOURCE1} docs

for m in dhcp6c.8 dhcp6s.8 dhcp6r.8 dhcp6c.conf.5 dhcp6s.conf.5 ; do
    %{__mv} $m $m.dos
    tr -d '\r' < $m.dos > $m
done

%install
%{__rm} -rf %{buildroot}
%{__make} install DESTDIR=%{buildroot}
%{__mkdir} -p %{buildroot}%{_localstatedir}/lib/dhcpv6

%post
chkconfig --add dhcp6s

%preun
if [ $1 = 0 ]; then
    service dhcp6s stop > /dev/null 2>&1
    chkconfig --del dhcp6s || :
fi

%postun
if [ "$1" -ge "1" ]; then
    service dhcp6s condrestart >/dev/null 2>&1 || :
fi

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-,root,root,-)
%attr(754,root,root) %{_sbindir}/dhcp6s
%attr(754,root,root) %{_sbindir}/dhcp6r
%attr(755,root,root) %config /etc/rc.d/init.d/dhcp6s
%attr(755,root,root) %config /etc/rc.d/init.d/dhcp6r
%config(noreplace) /etc/sysconfig/dhcp6s
%config(noreplace) /etc/sysconfig/dhcp6r
%{_mandir}/man8/dhcp6s.8.gz
%{_mandir}/man5/dhcp6s.conf.5.gz
%{_mandir}/man8/dhcp6r.8.gz
%attr(750,root,root) %dir %{_localstatedir}/lib/dhcpv6

%doc ReadMe docs/* dhcp6s.conf

%files -n dhcpv6_client
%defattr(-,root,root,-)
%attr(750,root,root) /sbin/dhcp6c
%{_mandir}/man8/dhcp6c.8.gz
%{_mandir}/man5/dhcp6c.conf.5.gz
%doc ReadMe dhcp6c.conf
%attr(750,root,root) %dir %{_localstatedir}/lib/dhcpv6

%changelog
* Thu May 29 2008 David Cantrell <dcantrell@redhat.com> - 0.10-24_EL4
- Correct behavior of 'restart' in the dhcp6r and dhcp6s init scripts
  Related: rhbz#237972

* Tue May 20 2008 David Cantrell <dcantrell@redhat.com> - 0.10-23_EL4
- Prevent dhcp6r and dhcp6s from running at the same time.  Correct some
  invalid clean up operations during init script failures.
  Related: rhbz#237972

* Thu May 15 2008 David Cantrell <dcantrell@redhat.com> - 0.10-22_EL4
- Do not use pidfileofproc() in dhcp6r init script, it returns the PID
  of the process, not the path to the pidfile
  Related: rhbz#237972

* Tue Apr 08 2008 David Cantrell <dcantrell@redhat.com> - 0.10-21_EL4
- Make sure pid file is removed on stop from dhcp6r init script
  Related: rhbz#237972

* Wed Apr 02 2008 David Cantrell <dcantrell@redhat.com> - 0.10-20_EL4
- Correct 'Usage:' line in dhcp6r error/help output to show valid options
  Related: rhbz#237972
- Avoid printing two status lines in the stop() functions of dhcp6s and dhcp6r
  Related: rhbz#237972

* Wed Mar 26 2008 David Cantrell <dcantrell@redhat.com> - 0.10-19_EL4
- Correct 'Usage:' line in dhcp6s error/help output to show valid options
  Related: rhbz#237972

* Thu Feb 14 2008 David Cantrell <dcantrell@redhat.com> - 0.10-18_EL4
- Updated dhcp6r and dhcp6s init scripts to conform to script guidelines
  Resolves: rhbz#237972

* Tue Feb 06 2007 David Cantrell <dcantrell@redhat.com> - 0.10-17_EL4
- Added missing ';;' in dhcp6r init script
- Related: rhbz#217309

* Tue Feb 06 2007 David Cantrell <dcantrell@redhat.com> - 0.10-16_EL4
- Make dhcp6r and dhcp6s init scripts LSB compliant
- Related: rhbz#217309

* Mon Nov 27 2006 David Cantrell <dcantrell@redhat.com> - 0.10-15_EL4
- server6_addr.conf is not required for dhcp6s
- Resolves: rhbz#217309
- Man page for dhcp6s.conf should reference server-preference
- Resolves: rhbz#217308

* Mon Aug 15 2005 Jason Vas Dias <jvdias@redhat.com>
- fix bug 165882: allow client to configure an interface which
  does not have an IPv4 address ( use getifaddrs instead of
  ioctl(sockfd, SIOGIFCONF, ...)
- fix bug 165884 (possibly!): force use of glibc's getifaddrs,
  not internal getifaddrs implementation

* Fri Apr 01 2005 Florian La Roche <laroche@redhat.com>
- made perms for /var/lib/dhcpv6 the same

* Fri Mar 25 2005 Florian La Roche <laroche@redhat.com>
- add "exit 0" to postun script

* Thu Jan 13 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Fix misc. compiler warnings and ms-dos formatted man-pages

* Wed Jan 12 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-11
- Add 'prefix-delegation-interface' option to allow write
- of radvd interface configuration other than that for 
- the interface the lease was received on.

* Mon Jan 10 2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Fix bug 144585: dhcp6c wasn't writing radvd.conf in prefix delegation mode

* Sun Jan 9  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-10
- Add Relay Agent support. Thanks to  Brian Bluesker<bbuesker@qualcomm.com>
- for the patch to add relay support to the server and for submitting the 
- patch originally contributed by Cristian Cadar of NEC Europe to 
- DHCPv6-developer  mailing list.

* Fri Jan 7  2005 Jason Vas Dias <jvdias@redhat.com> - 0.10-9
- fix bug 143728: SEGV core on resolv.conf + radvd.conf update -
- yywrap()'s must return 1

* Mon Oct 18 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-7
- fix bug 136146: clean up code - prevent compiler warnings

* Mon Sep 13 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-6
- fix bug 132468 for bug 125712: invoke change_resolv_conf

* Mon Sep 13 2004 Bill Nottingham <notting@redhat.com> - 0.10-5
- don't run by default
- add chkconfig prereqs, postun script, etc.

* Thu Sep  2 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-3/4
- fixed missing %defattr for dhcpv6_client - bug 131638

* Mon Aug 30 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-2
- Split into two packages: dhcpv6-*, containing server only,
- and dhcpv6_client-*, containing client only.

* Thu Aug 26 2004 Jason Vas Dias <jvdias@redhat.com> - 0.10-1 
- Initial build.

